// This file is part of VKF, a CPython library
// for Machine Learning based on Lattice Theory.
//
// Copyright (c) 2020 Dmitry V. Vinogradov
//
// This Source Code Form is subject to the terms of the X11 (MIT)
// License. If a copy of the X11 License was not distributed
// with this file, You can obtain one at https://opensource.org/licenses/MIT/.

#ifndef VKF_FRAGMENT_HPP
#define VKF_FRAGMENT_HPP

#include <cstdlib> // for std namespace
#include <fstream> // for std::ifstream, std::ofstream
#include <ios> // for std::ios::eof() function
#include <iostream> // for std::cout, std::cerr
#include <list> // for std::list
#include <memory> // for std::unique_ptr
#include <random> // for std::mt19937_64, std::uniform_int_distribution<>
#include <string> // for std::string
#include <utility> // for std::move()
#include <vector> // for std::vector

#include <boost/config.hpp> // for BOOST_SYMBOL_EXPORT
#include <boost/dll.hpp> // for boost::dll::import_alias, BOOST_DLL_ALIAS :error with MinGW64
#include <boost/dll/import.hpp> // for boost::dll::import
#include <boost/dynamic_bitset.hpp>

#ifndef API
// `extern "C"` - specifies C linkage: forces the compiler to export function/variable by a pretty (unmangled) C name
#define API extern "C" BOOST_SYMBOL_EXPORT
#endif //API

namespace vkf {
//    class BOOST_SYMBOL_EXPORT Fragment: public boost::dynamic_bitset<boost::dynamic_bitset<>::block_type> {
    class Fragment: public boost::dynamic_bitset<boost::dynamic_bitset<>::block_type> {
        protected:
        private:
        public:
            Fragment() = default;
            // Fragment constructor from move-constructor of base class
            Fragment(boost::dynamic_bitset<boost::dynamic_bitset<>::block_type>&& dbs) :
                boost::dynamic_bitset<boost::dynamic_bitset<>::block_type>(dbs) {}
    };

    typedef std::unique_ptr<Fragment> FragmentPtr;
} // namespace vkf

#endif // VKF_FRAGMENT_HPP
